# core-image-tester
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

"""Constants for this service."""

# Queue names are constant, rather than being defined in the config.

# The queue we listen to for new payloads to check:
INPUT_QUEUE = "snappy-proposed.results.v1"

# The queue we put fatally error'd payloads into:
DEAD_LETTER_QUEUE = "snappy-proposed.deadletters.v1"

# The queue we put payloads on to re-run the test:
TEST_RETRY_QUEUE = "snappy-proposed.packages.v1"

# The exchange we put results on:
DONE_EXCHANGE = "results.exchange"


SOLUTION_NAME = "snappy-proposed"

SERVICE_NAME = "result-checker"


def _get_hostname():
    """Return sanitized contents of /etc/hostname.

    It is necessary because current juju hostnames (juju-<env-name>-machine-#)
    are too big due to our long environment names ('<spec_name>-<MD5>').
    Linux (DNS for RFC1035, really) only supports labels up to 64 chars and
    the fallback varies from tool to tool, `cloud-init` chokes on longer
    names and sets 'ubuntu' (which is the value considered by socket.get*),
    `hostnamectl` (systemd) would truncate the given data.

    None of this is ideal to our applications, that's why we will operate
    on the pristine /etc/hostname and remove the 'juju-' and '-machine' terms
    added by juju.
    """
    with open('/etc/hostname') as fd:
        hostname = fd.read()
    return hostname.replace('juju-', '').replace('-machine', '').strip()


HOSTNAME = _get_hostname()

LOGGING_EXTRA = {
    'solution': SOLUTION_NAME,
    'service': SERVICE_NAME,
    'hostname': HOSTNAME,
}
